package br.com.bookstore.bean;

import java.util.ArrayList;
import java.util.List;

import br.com.bookstore.model.exceptions.LivroException;
import br.com.bookstore.model.livro.Livro;

/**
 * Fachada que concentra o ponto de entrada para todas
 * as operaes que envolvem o gerenciamento de livros EJB Livro.
 * 
 * @author Adelino Ferreira- bugass@gmail.com
 */
public interface LivroBeanModel {

	/**
	 * Realiza o cadastro de um novo Livro.
	 * 
	 * @param livro o livro a ser cadastrado.
	 * @throws LivroException Caso o livro a ser cadastrado j exista na base de dados ou possua alguma
	 * 							informao invlida..
	 */
	public void cadastrarLivro( Livro livro ) throws LivroException;
	
	/**
	 * Exclui um livro da base de dados da aplicao.
	 * 
	 * @param livro O Livro a ser removido
	 * @throws LivroException Caso o livro a ser removido no exista.
	 */
	public void removerLivro( Livro livro ) throws LivroException;
	
	/**
	 * Permite modificar as informaes cadastrais de um livro. No deve ser possvel alterar o ISBN
	 * do livro. As informaes atuais do livro existente na base de dados sero subistitudas pelas 
	 * informaes fornecidas atravs do objeto passado como parmetro.
	 * 
	 * @param livro O livro cujas informaes sero modificadas.
	 * @throws LivroException Caso existam restries nos dados fornecidos atravs do novo objeto passado
	 * 							como parmetro ou o livro a ser modificado no exista nas bases de dados.
	 */
	public void editarLivro( Livro livro ) throws LivroException;
	
	/**
	 * Obtm uma lista com todos os livros cadastrados na aplicao.
	 * 
	 * @return Uma lista com todos os livros cadastrados, ou uma lista vazia, caso no exista nenhum
	 * 			livro cadastrado.
	 */
	public List<Livro> listarLivros();

	/**
	 * Obtm o livro representado pelo ISBN passado como parmetro. 
	 * 
	 * @param isbn o ISBN usado para recuperar o livro especfico.
	 * @return o livro cujo ISBN foi passado como parmetro, ou null, caso no exista livro cadastrado
	 * 			com o ISBN em questo.
	 * @throws LivroException 
	 */
	public Livro obterLivro( String isbn ) throws LivroException;
	
	
	public ArrayList<Livro> buscaLivro(String dado) throws LivroException;
	
}
