package br.com.bookstore.integracao;

import java.util.ArrayList;
import java.util.List;

import br.com.bookstore.model.livro.Livro;

public interface LivroDao {

	/**
	 * Realiza o cadastro de um novo Livro.
	 * 
	 * @param livro o livro a ser cadastrado.
	 * @throws LivroException Caso o livro a ser cadastrado j exista na base de dados ou possua alguma
	 * 							informao invlida..
	 */
	public void insertLivro( Livro livro );
	
	/**
	 * Exclui um livro da base de dados da aplicao.
	 * 
	 * @param livro O Livro a ser removido
	 * @throws LivroException Caso o livro a ser removido no exista.
	 */
	public void deleteLivro( Livro livro ) throws Exception;
	
	/**
	 * Permite modificar as informaes cadastrais de um livro. No deve ser possvel alterar o ISBN
	 * do livro. As informaes atuais do livro existente na base de dados sero subistitudas pelas 
	 * informaes fornecidas atravs do objeto passado como parmetro.
	 * 
	 * @param livro O livro cujas informaes sero modificadas.
	 * @throws LivroException Caso existam restries nos dados fornecidos atravs do novo objeto passado
	 * 							como parmetro ou o livro a ser modificado no exista nas bases de dados.
	 */
	public void updateLivro( Livro livro );
	
	/**
	 * Obtm uma lista com todos os livros cadastrados na aplicao.
	 * 
	 * @return Uma lista com todos os livros cadastrados, ou uma lista vazia, caso no exista nenhum
	 * 			livro cadastrado.
	 */
	public List<Livro> selectLivros();

	/**
	 * Obtm o livro representado pelo ISBN passado como parmetro. 
	 * 
	 * @param isbn o ISBN usado para recuperar o livro especfico.
	 * @return o livro cujo ISBN foi passado como parmetro, ou null, caso no exista livro cadastrado
	 * 			com o ISBN em questo.
	 */
	public Livro getLivro( String isbn ) throws Exception;
	
	
	public ArrayList<Livro> searchLivro(String dado) throws Exception;
	
}
